# coding: utf-8

"""
    Radarr

    Radarr API docs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel

class IndexerConfigResource(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    id: Optional[int]
    minimum_age: Optional[int]
    maximum_size: Optional[int]
    retention: Optional[int]
    rss_sync_interval: Optional[int]
    prefer_indexer_flags: Optional[bool]
    availability_delay: Optional[int]
    allow_hardcoded_subs: Optional[bool]
    whitelisted_hardcoded_subs: Optional[str]
    __properties = ["id", "minimumAge", "maximumSize", "retention", "rssSyncInterval", "preferIndexerFlags", "availabilityDelay", "allowHardcodedSubs", "whitelistedHardcodedSubs"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True
        alias_generator = lambda x: x.split("_")[0] + "".join(word.capitalize() for word in x.split("_")[1:])

    def __getitem__(self, item):
        return getattr(self, item)

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> IndexerConfigResource:
        """Create an instance of IndexerConfigResource from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # set to None if whitelisted_hardcoded_subs (nullable) is None
        if self.whitelisted_hardcoded_subs is None:
            _dict['whitelistedHardcodedSubs'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> IndexerConfigResource:
        """Create an instance of IndexerConfigResource from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return IndexerConfigResource.parse_obj(obj)

        _obj = IndexerConfigResource.parse_obj({
            "id": obj.get("id"),
            "minimum_age": obj.get("minimumAge"),
            "maximum_size": obj.get("maximumSize"),
            "retention": obj.get("retention"),
            "rss_sync_interval": obj.get("rssSyncInterval"),
            "prefer_indexer_flags": obj.get("preferIndexerFlags"),
            "availability_delay": obj.get("availabilityDelay"),
            "allow_hardcoded_subs": obj.get("allowHardcodedSubs"),
            "whitelisted_hardcoded_subs": obj.get("whitelistedHardcodedSubs")
        })
        return _obj




# coding: utf-8

"""
    Radarr

    Radarr API docs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel
from whisparr.models.add_movie_method import AddMovieMethod
from whisparr.models.monitor_types import MonitorTypes

class AddMovieOptions(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    ignore_episodes_with_files: Optional[bool]
    ignore_episodes_without_files: Optional[bool]
    monitor: Optional[MonitorTypes]
    search_for_movie: Optional[bool]
    add_method: Optional[AddMovieMethod]
    __properties = ["ignoreEpisodesWithFiles", "ignoreEpisodesWithoutFiles", "monitor", "searchForMovie", "addMethod"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True
        alias_generator = lambda x: x.split("_")[0] + "".join(word.capitalize() for word in x.split("_")[1:])

    def __getitem__(self, item):
        return getattr(self, item)

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> AddMovieOptions:
        """Create an instance of AddMovieOptions from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> AddMovieOptions:
        """Create an instance of AddMovieOptions from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return AddMovieOptions.parse_obj(obj)

        _obj = AddMovieOptions.parse_obj({
            "ignore_episodes_with_files": obj.get("ignoreEpisodesWithFiles"),
            "ignore_episodes_without_files": obj.get("ignoreEpisodesWithoutFiles"),
            "monitor": obj.get("monitor"),
            "search_for_movie": obj.get("searchForMovie"),
            "add_method": obj.get("addMethod")
        })
        return _obj




# coding: utf-8

"""
    Radarr

    Radarr API docs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Generated by: https://openapi-generator.tech
"""


from inspect import getfullargspec
import pprint
import re  # noqa: F401
from aenum import Enum, no_arg





class SourceType(str, Enum):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    allowed enum values
    """

    TMDB = 'tmdb'
    MAPPINGS = 'mappings'
    USER = 'user'
    INDEXER = 'indexer'




# coding: utf-8

"""
    Radarr

    Radarr API docs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from typing import List, Optional
from pydantic import BaseModel
from whisparr.models.add_movie_options import AddMovieOptions
from whisparr.models.alternative_title_resource import AlternativeTitleResource
from whisparr.models.language import Language
from whisparr.models.media_cover import MediaCover
from whisparr.models.movie_collection import MovieCollection
from whisparr.models.movie_file_resource import MovieFileResource
from whisparr.models.movie_status_type import MovieStatusType
from whisparr.models.ratings import Ratings

class MovieResource(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    id: Optional[int]
    title: Optional[str]
    original_title: Optional[str]
    original_language: Optional[Language]
    alternate_titles: Optional[List]
    secondary_year: Optional[int]
    secondary_year_source_id: Optional[int]
    sort_title: Optional[str]
    size_on_disk: Optional[int]
    status: Optional[MovieStatusType]
    overview: Optional[str]
    in_cinemas: Optional[datetime]
    physical_release: Optional[datetime]
    digital_release: Optional[datetime]
    physical_release_note: Optional[str]
    images: Optional[List]
    website: Optional[str]
    remote_poster: Optional[str]
    year: Optional[int]
    has_file: Optional[bool]
    you_tube_trailer_id: Optional[str]
    studio: Optional[str]
    path: Optional[str]
    quality_profile_id: Optional[int]
    monitored: Optional[bool]
    minimum_availability: Optional[MovieStatusType]
    is_available: Optional[bool]
    folder_name: Optional[str]
    runtime: Optional[int]
    clean_title: Optional[str]
    imdb_id: Optional[str]
    tmdb_id: Optional[int]
    title_slug: Optional[str]
    root_folder_path: Optional[str]
    folder: Optional[str]
    certification: Optional[str]
    genres: Optional[List]
    tags: Optional[List]
    added: Optional[datetime]
    add_options: Optional[AddMovieOptions]
    ratings: Optional[Ratings]
    movie_file: Optional[MovieFileResource]
    collection: Optional[MovieCollection]
    popularity: Optional[float]
    __properties = ["id", "title", "originalTitle", "originalLanguage", "alternateTitles", "secondaryYear", "secondaryYearSourceId", "sortTitle", "sizeOnDisk", "status", "overview", "inCinemas", "physicalRelease", "digitalRelease", "physicalReleaseNote", "images", "website", "remotePoster", "year", "hasFile", "youTubeTrailerId", "studio", "path", "qualityProfileId", "monitored", "minimumAvailability", "isAvailable", "folderName", "runtime", "cleanTitle", "imdbId", "tmdbId", "titleSlug", "rootFolderPath", "folder", "certification", "genres", "tags", "added", "addOptions", "ratings", "movieFile", "collection", "popularity"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True
        alias_generator = lambda x: x.split("_")[0] + "".join(word.capitalize() for word in x.split("_")[1:])

    def __getitem__(self, item):
        return getattr(self, item)

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> MovieResource:
        """Create an instance of MovieResource from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of original_language
        if self.original_language:
            _dict['originalLanguage'] = self.original_language.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in alternate_titles (list)
        _items = []
        if self.alternate_titles:
            for _item in self.alternate_titles:
                if _item:
                    _items.append(_item.to_dict())
            _dict['alternateTitles'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in images (list)
        _items = []
        if self.images:
            for _item in self.images:
                if _item:
                    _items.append(_item.to_dict())
            _dict['images'] = _items
        # override the default output from pydantic by calling `to_dict()` of add_options
        if self.add_options:
            _dict['addOptions'] = self.add_options.to_dict()
        # override the default output from pydantic by calling `to_dict()` of ratings
        if self.ratings:
            _dict['ratings'] = self.ratings.to_dict()
        # override the default output from pydantic by calling `to_dict()` of movie_file
        if self.movie_file:
            _dict['movieFile'] = self.movie_file.to_dict()
        # override the default output from pydantic by calling `to_dict()` of collection
        if self.collection:
            _dict['collection'] = self.collection.to_dict()
        # set to None if title (nullable) is None
        if self.title is None:
            _dict['title'] = None

        # set to None if original_title (nullable) is None
        if self.original_title is None:
            _dict['originalTitle'] = None

        # set to None if alternate_titles (nullable) is None
        if self.alternate_titles is None:
            _dict['alternateTitles'] = None

        # set to None if secondary_year (nullable) is None
        if self.secondary_year is None:
            _dict['secondaryYear'] = None

        # set to None if sort_title (nullable) is None
        if self.sort_title is None:
            _dict['sortTitle'] = None

        # set to None if size_on_disk (nullable) is None
        if self.size_on_disk is None:
            _dict['sizeOnDisk'] = None

        # set to None if overview (nullable) is None
        if self.overview is None:
            _dict['overview'] = None

        # set to None if in_cinemas (nullable) is None
        if self.in_cinemas is None:
            _dict['inCinemas'] = None

        # set to None if physical_release (nullable) is None
        if self.physical_release is None:
            _dict['physicalRelease'] = None

        # set to None if digital_release (nullable) is None
        if self.digital_release is None:
            _dict['digitalRelease'] = None

        # set to None if physical_release_note (nullable) is None
        if self.physical_release_note is None:
            _dict['physicalReleaseNote'] = None

        # set to None if images (nullable) is None
        if self.images is None:
            _dict['images'] = None

        # set to None if website (nullable) is None
        if self.website is None:
            _dict['website'] = None

        # set to None if remote_poster (nullable) is None
        if self.remote_poster is None:
            _dict['remotePoster'] = None

        # set to None if you_tube_trailer_id (nullable) is None
        if self.you_tube_trailer_id is None:
            _dict['youTubeTrailerId'] = None

        # set to None if studio (nullable) is None
        if self.studio is None:
            _dict['studio'] = None

        # set to None if path (nullable) is None
        if self.path is None:
            _dict['path'] = None

        # set to None if folder_name (nullable) is None
        if self.folder_name is None:
            _dict['folderName'] = None

        # set to None if clean_title (nullable) is None
        if self.clean_title is None:
            _dict['cleanTitle'] = None

        # set to None if imdb_id (nullable) is None
        if self.imdb_id is None:
            _dict['imdbId'] = None

        # set to None if title_slug (nullable) is None
        if self.title_slug is None:
            _dict['titleSlug'] = None

        # set to None if root_folder_path (nullable) is None
        if self.root_folder_path is None:
            _dict['rootFolderPath'] = None

        # set to None if folder (nullable) is None
        if self.folder is None:
            _dict['folder'] = None

        # set to None if certification (nullable) is None
        if self.certification is None:
            _dict['certification'] = None

        # set to None if genres (nullable) is None
        if self.genres is None:
            _dict['genres'] = None

        # set to None if tags (nullable) is None
        if self.tags is None:
            _dict['tags'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> MovieResource:
        """Create an instance of MovieResource from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return MovieResource.parse_obj(obj)

        _obj = MovieResource.parse_obj({
            "id": obj.get("id"),
            "title": obj.get("title"),
            "original_title": obj.get("originalTitle"),
            "original_language": Language.from_dict(obj.get("originalLanguage")) if obj.get("originalLanguage") is not None else None,
            "alternate_titles": [AlternativeTitleResource.from_dict(_item) for _item in obj.get("alternateTitles")] if obj.get("alternateTitles") is not None else None,
            "secondary_year": obj.get("secondaryYear"),
            "secondary_year_source_id": obj.get("secondaryYearSourceId"),
            "sort_title": obj.get("sortTitle"),
            "size_on_disk": obj.get("sizeOnDisk"),
            "status": obj.get("status"),
            "overview": obj.get("overview"),
            "in_cinemas": obj.get("inCinemas"),
            "physical_release": obj.get("physicalRelease"),
            "digital_release": obj.get("digitalRelease"),
            "physical_release_note": obj.get("physicalReleaseNote"),
            "images": [MediaCover.from_dict(_item) for _item in obj.get("images")] if obj.get("images") is not None else None,
            "website": obj.get("website"),
            "remote_poster": obj.get("remotePoster"),
            "year": obj.get("year"),
            "has_file": obj.get("hasFile"),
            "you_tube_trailer_id": obj.get("youTubeTrailerId"),
            "studio": obj.get("studio"),
            "path": obj.get("path"),
            "quality_profile_id": obj.get("qualityProfileId"),
            "monitored": obj.get("monitored"),
            "minimum_availability": obj.get("minimumAvailability"),
            "is_available": obj.get("isAvailable"),
            "folder_name": obj.get("folderName"),
            "runtime": obj.get("runtime"),
            "clean_title": obj.get("cleanTitle"),
            "imdb_id": obj.get("imdbId"),
            "tmdb_id": obj.get("tmdbId"),
            "title_slug": obj.get("titleSlug"),
            "root_folder_path": obj.get("rootFolderPath"),
            "folder": obj.get("folder"),
            "certification": obj.get("certification"),
            "genres": obj.get("genres"),
            "tags": obj.get("tags"),
            "added": obj.get("added"),
            "add_options": AddMovieOptions.from_dict(obj.get("addOptions")) if obj.get("addOptions") is not None else None,
            "ratings": Ratings.from_dict(obj.get("ratings")) if obj.get("ratings") is not None else None,
            "movie_file": MovieFileResource.from_dict(obj.get("movieFile")) if obj.get("movieFile") is not None else None,
            "collection": MovieCollection.from_dict(obj.get("collection")) if obj.get("collection") is not None else None,
            "popularity": obj.get("popularity")
        })
        return _obj




# coding: utf-8

"""
    Radarr

    Radarr API docs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel
from whisparr.models.movie_resource import MovieResource
from whisparr.models.parsed_movie_info import ParsedMovieInfo

class ParseResource(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    id: Optional[int]
    title: Optional[str]
    parsed_movie_info: Optional[ParsedMovieInfo]
    movie: Optional[MovieResource]
    __properties = ["id", "title", "parsedMovieInfo", "movie"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True
        alias_generator = lambda x: x.split("_")[0] + "".join(word.capitalize() for word in x.split("_")[1:])

    def __getitem__(self, item):
        return getattr(self, item)

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> ParseResource:
        """Create an instance of ParseResource from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of parsed_movie_info
        if self.parsed_movie_info:
            _dict['parsedMovieInfo'] = self.parsed_movie_info.to_dict()
        # override the default output from pydantic by calling `to_dict()` of movie
        if self.movie:
            _dict['movie'] = self.movie.to_dict()
        # set to None if title (nullable) is None
        if self.title is None:
            _dict['title'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ParseResource:
        """Create an instance of ParseResource from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return ParseResource.parse_obj(obj)

        _obj = ParseResource.parse_obj({
            "id": obj.get("id"),
            "title": obj.get("title"),
            "parsed_movie_info": ParsedMovieInfo.from_dict(obj.get("parsedMovieInfo")) if obj.get("parsedMovieInfo") is not None else None,
            "movie": MovieResource.from_dict(obj.get("movie")) if obj.get("movie") is not None else None
        })
        return _obj




# coding: utf-8

"""
    Radarr

    Radarr API docs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel
from whisparr.models.rating_child import RatingChild

class Ratings(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    imdb: Optional[RatingChild]
    tmdb: Optional[RatingChild]
    metacritic: Optional[RatingChild]
    rotten_tomatoes: Optional[RatingChild]
    __properties = ["imdb", "tmdb", "metacritic", "rottenTomatoes"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True
        alias_generator = lambda x: x.split("_")[0] + "".join(word.capitalize() for word in x.split("_")[1:])

    def __getitem__(self, item):
        return getattr(self, item)

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Ratings:
        """Create an instance of Ratings from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of imdb
        if self.imdb:
            _dict['imdb'] = self.imdb.to_dict()
        # override the default output from pydantic by calling `to_dict()` of tmdb
        if self.tmdb:
            _dict['tmdb'] = self.tmdb.to_dict()
        # override the default output from pydantic by calling `to_dict()` of metacritic
        if self.metacritic:
            _dict['metacritic'] = self.metacritic.to_dict()
        # override the default output from pydantic by calling `to_dict()` of rotten_tomatoes
        if self.rotten_tomatoes:
            _dict['rottenTomatoes'] = self.rotten_tomatoes.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> Ratings:
        """Create an instance of Ratings from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return Ratings.parse_obj(obj)

        _obj = Ratings.parse_obj({
            "imdb": RatingChild.from_dict(obj.get("imdb")) if obj.get("imdb") is not None else None,
            "tmdb": RatingChild.from_dict(obj.get("tmdb")) if obj.get("tmdb") is not None else None,
            "metacritic": RatingChild.from_dict(obj.get("metacritic")) if obj.get("metacritic") is not None else None,
            "rotten_tomatoes": RatingChild.from_dict(obj.get("rottenTomatoes")) if obj.get("rottenTomatoes") is not None else None
        })
        return _obj




# coding: utf-8

"""
    Radarr

    Radarr API docs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel

class DownloadClientConfigResource(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    id: Optional[int]
    download_client_working_folders: Optional[str]
    enable_completed_download_handling: Optional[bool]
    check_for_finished_download_interval: Optional[int]
    auto_redownload_failed: Optional[bool]
    __properties = ["id", "downloadClientWorkingFolders", "enableCompletedDownloadHandling", "checkForFinishedDownloadInterval", "autoRedownloadFailed"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True
        alias_generator = lambda x: x.split("_")[0] + "".join(word.capitalize() for word in x.split("_")[1:])

    def __getitem__(self, item):
        return getattr(self, item)

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> DownloadClientConfigResource:
        """Create an instance of DownloadClientConfigResource from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # set to None if download_client_working_folders (nullable) is None
        if self.download_client_working_folders is None:
            _dict['downloadClientWorkingFolders'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> DownloadClientConfigResource:
        """Create an instance of DownloadClientConfigResource from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return DownloadClientConfigResource.parse_obj(obj)

        _obj = DownloadClientConfigResource.parse_obj({
            "id": obj.get("id"),
            "download_client_working_folders": obj.get("downloadClientWorkingFolders"),
            "enable_completed_download_handling": obj.get("enableCompletedDownloadHandling"),
            "check_for_finished_download_interval": obj.get("checkForFinishedDownloadInterval"),
            "auto_redownload_failed": obj.get("autoRedownloadFailed")
        })
        return _obj




# coding: utf-8

"""
    Radarr

    Radarr API docs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from typing import List, Optional
from pydantic import BaseModel
from whisparr.models.media_cover import MediaCover
from whisparr.models.movie_metadata import MovieMetadata
from whisparr.models.movie_status_type import MovieStatusType

class MovieCollection(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    id: Optional[int]
    title: Optional[str]
    clean_title: Optional[str]
    sort_title: Optional[str]
    tmdb_id: Optional[int]
    overview: Optional[str]
    monitored: Optional[bool]
    quality_profile_id: Optional[int]
    root_folder_path: Optional[str]
    search_on_add: Optional[bool]
    minimum_availability: Optional[MovieStatusType]
    last_info_sync: Optional[datetime]
    images: Optional[List]
    added: Optional[datetime]
    movies: Optional[List]
    __properties = ["id", "title", "cleanTitle", "sortTitle", "tmdbId", "overview", "monitored", "qualityProfileId", "rootFolderPath", "searchOnAdd", "minimumAvailability", "lastInfoSync", "images", "added", "movies"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True
        alias_generator = lambda x: x.split("_")[0] + "".join(word.capitalize() for word in x.split("_")[1:])

    def __getitem__(self, item):
        return getattr(self, item)

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> MovieCollection:
        """Create an instance of MovieCollection from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of each item in images (list)
        _items = []
        if self.images:
            for _item in self.images:
                if _item:
                    _items.append(_item.to_dict())
            _dict['images'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in movies (list)
        _items = []
        if self.movies:
            for _item in self.movies:
                if _item:
                    _items.append(_item.to_dict())
            _dict['movies'] = _items
        # set to None if title (nullable) is None
        if self.title is None:
            _dict['title'] = None

        # set to None if clean_title (nullable) is None
        if self.clean_title is None:
            _dict['cleanTitle'] = None

        # set to None if sort_title (nullable) is None
        if self.sort_title is None:
            _dict['sortTitle'] = None

        # set to None if overview (nullable) is None
        if self.overview is None:
            _dict['overview'] = None

        # set to None if root_folder_path (nullable) is None
        if self.root_folder_path is None:
            _dict['rootFolderPath'] = None

        # set to None if last_info_sync (nullable) is None
        if self.last_info_sync is None:
            _dict['lastInfoSync'] = None

        # set to None if images (nullable) is None
        if self.images is None:
            _dict['images'] = None

        # set to None if movies (nullable) is None
        if self.movies is None:
            _dict['movies'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> MovieCollection:
        """Create an instance of MovieCollection from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return MovieCollection.parse_obj(obj)

        _obj = MovieCollection.parse_obj({
            "id": obj.get("id"),
            "title": obj.get("title"),
            "clean_title": obj.get("cleanTitle"),
            "sort_title": obj.get("sortTitle"),
            "tmdb_id": obj.get("tmdbId"),
            "overview": obj.get("overview"),
            "monitored": obj.get("monitored"),
            "quality_profile_id": obj.get("qualityProfileId"),
            "root_folder_path": obj.get("rootFolderPath"),
            "search_on_add": obj.get("searchOnAdd"),
            "minimum_availability": obj.get("minimumAvailability"),
            "last_info_sync": obj.get("lastInfoSync"),
            "images": [MediaCover.from_dict(_item) for _item in obj.get("images")] if obj.get("images") is not None else None,
            "added": obj.get("added"),
            "movies": [MovieMetadata.from_dict(_item) for _item in obj.get("movies")] if obj.get("movies") is not None else None
        })
        return _obj




# coding: utf-8

"""
    Radarr

    Radarr API docs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Generated by: https://openapi-generator.tech
"""


from inspect import getfullargspec
import pprint
import re  # noqa: F401
from aenum import Enum, no_arg





class TMDbCountryCode(str, Enum):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    allowed enum values
    """

    AU = 'au'
    BR = 'br'
    CA = 'ca'
    FR = 'fr'
    DE = 'de'
    GB = 'gb'
    IE = 'ie'
    IT = 'it'
    ES = 'es'
    US = 'us'
    NZ = 'nz'




# coding: utf-8

"""
    Radarr

    Radarr API docs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from typing import List, Optional
from pydantic import BaseModel
from whisparr.models.alternative_title import AlternativeTitle
from whisparr.models.language import Language
from whisparr.models.media_cover import MediaCover
from whisparr.models.movie_status_type import MovieStatusType
from whisparr.models.movie_translation import MovieTranslation
from whisparr.models.ratings import Ratings

class MovieMetadata(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    id: Optional[int]
    tmdb_id: Optional[int]
    images: Optional[List]
    genres: Optional[List]
    in_cinemas: Optional[datetime]
    physical_release: Optional[datetime]
    digital_release: Optional[datetime]
    certification: Optional[str]
    year: Optional[int]
    ratings: Optional[Ratings]
    collection_tmdb_id: Optional[int]
    collection_title: Optional[str]
    last_info_sync: Optional[datetime]
    runtime: Optional[int]
    website: Optional[str]
    imdb_id: Optional[str]
    title: Optional[str]
    clean_title: Optional[str]
    sort_title: Optional[str]
    status: Optional[MovieStatusType]
    overview: Optional[str]
    alternative_titles: Optional[List]
    translations: Optional[List]
    secondary_year: Optional[int]
    you_tube_trailer_id: Optional[str]
    studio: Optional[str]
    original_title: Optional[str]
    clean_original_title: Optional[str]
    original_language: Optional[Language]
    recommendations: Optional[List]
    popularity: Optional[float]
    is_recent_movie: Optional[bool]
    __properties = ["id", "tmdbId", "images", "genres", "inCinemas", "physicalRelease", "digitalRelease", "certification", "year", "ratings", "collectionTmdbId", "collectionTitle", "lastInfoSync", "runtime", "website", "imdbId", "title", "cleanTitle", "sortTitle", "status", "overview", "alternativeTitles", "translations", "secondaryYear", "youTubeTrailerId", "studio", "originalTitle", "cleanOriginalTitle", "originalLanguage", "recommendations", "popularity", "isRecentMovie"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True
        alias_generator = lambda x: x.split("_")[0] + "".join(word.capitalize() for word in x.split("_")[1:])

    def __getitem__(self, item):
        return getattr(self, item)

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> MovieMetadata:
        """Create an instance of MovieMetadata from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                            "is_recent_movie",
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of each item in images (list)
        _items = []
        if self.images:
            for _item in self.images:
                if _item:
                    _items.append(_item.to_dict())
            _dict['images'] = _items
        # override the default output from pydantic by calling `to_dict()` of ratings
        if self.ratings:
            _dict['ratings'] = self.ratings.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in alternative_titles (list)
        _items = []
        if self.alternative_titles:
            for _item in self.alternative_titles:
                if _item:
                    _items.append(_item.to_dict())
            _dict['alternativeTitles'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in translations (list)
        _items = []
        if self.translations:
            for _item in self.translations:
                if _item:
                    _items.append(_item.to_dict())
            _dict['translations'] = _items
        # override the default output from pydantic by calling `to_dict()` of original_language
        if self.original_language:
            _dict['originalLanguage'] = self.original_language.to_dict()
        # set to None if images (nullable) is None
        if self.images is None:
            _dict['images'] = None

        # set to None if genres (nullable) is None
        if self.genres is None:
            _dict['genres'] = None

        # set to None if in_cinemas (nullable) is None
        if self.in_cinemas is None:
            _dict['inCinemas'] = None

        # set to None if physical_release (nullable) is None
        if self.physical_release is None:
            _dict['physicalRelease'] = None

        # set to None if digital_release (nullable) is None
        if self.digital_release is None:
            _dict['digitalRelease'] = None

        # set to None if certification (nullable) is None
        if self.certification is None:
            _dict['certification'] = None

        # set to None if collection_title (nullable) is None
        if self.collection_title is None:
            _dict['collectionTitle'] = None

        # set to None if last_info_sync (nullable) is None
        if self.last_info_sync is None:
            _dict['lastInfoSync'] = None

        # set to None if website (nullable) is None
        if self.website is None:
            _dict['website'] = None

        # set to None if imdb_id (nullable) is None
        if self.imdb_id is None:
            _dict['imdbId'] = None

        # set to None if title (nullable) is None
        if self.title is None:
            _dict['title'] = None

        # set to None if clean_title (nullable) is None
        if self.clean_title is None:
            _dict['cleanTitle'] = None

        # set to None if sort_title (nullable) is None
        if self.sort_title is None:
            _dict['sortTitle'] = None

        # set to None if overview (nullable) is None
        if self.overview is None:
            _dict['overview'] = None

        # set to None if alternative_titles (nullable) is None
        if self.alternative_titles is None:
            _dict['alternativeTitles'] = None

        # set to None if translations (nullable) is None
        if self.translations is None:
            _dict['translations'] = None

        # set to None if secondary_year (nullable) is None
        if self.secondary_year is None:
            _dict['secondaryYear'] = None

        # set to None if you_tube_trailer_id (nullable) is None
        if self.you_tube_trailer_id is None:
            _dict['youTubeTrailerId'] = None

        # set to None if studio (nullable) is None
        if self.studio is None:
            _dict['studio'] = None

        # set to None if original_title (nullable) is None
        if self.original_title is None:
            _dict['originalTitle'] = None

        # set to None if clean_original_title (nullable) is None
        if self.clean_original_title is None:
            _dict['cleanOriginalTitle'] = None

        # set to None if recommendations (nullable) is None
        if self.recommendations is None:
            _dict['recommendations'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> MovieMetadata:
        """Create an instance of MovieMetadata from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return MovieMetadata.parse_obj(obj)

        _obj = MovieMetadata.parse_obj({
            "id": obj.get("id"),
            "tmdb_id": obj.get("tmdbId"),
            "images": [MediaCover.from_dict(_item) for _item in obj.get("images")] if obj.get("images") is not None else None,
            "genres": obj.get("genres"),
            "in_cinemas": obj.get("inCinemas"),
            "physical_release": obj.get("physicalRelease"),
            "digital_release": obj.get("digitalRelease"),
            "certification": obj.get("certification"),
            "year": obj.get("year"),
            "ratings": Ratings.from_dict(obj.get("ratings")) if obj.get("ratings") is not None else None,
            "collection_tmdb_id": obj.get("collectionTmdbId"),
            "collection_title": obj.get("collectionTitle"),
            "last_info_sync": obj.get("lastInfoSync"),
            "runtime": obj.get("runtime"),
            "website": obj.get("website"),
            "imdb_id": obj.get("imdbId"),
            "title": obj.get("title"),
            "clean_title": obj.get("cleanTitle"),
            "sort_title": obj.get("sortTitle"),
            "status": obj.get("status"),
            "overview": obj.get("overview"),
            "alternative_titles": [AlternativeTitle.from_dict(_item) for _item in obj.get("alternativeTitles")] if obj.get("alternativeTitles") is not None else None,
            "translations": [MovieTranslation.from_dict(_item) for _item in obj.get("translations")] if obj.get("translations") is not None else None,
            "secondary_year": obj.get("secondaryYear"),
            "you_tube_trailer_id": obj.get("youTubeTrailerId"),
            "studio": obj.get("studio"),
            "original_title": obj.get("originalTitle"),
            "clean_original_title": obj.get("cleanOriginalTitle"),
            "original_language": Language.from_dict(obj.get("originalLanguage")) if obj.get("originalLanguage") is not None else None,
            "recommendations": obj.get("recommendations"),
            "popularity": obj.get("popularity"),
            "is_recent_movie": obj.get("isRecentMovie")
        })
        return _obj




# coding: utf-8

"""
    Radarr

    Radarr API docs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import List, Optional
from pydantic import BaseModel
from whisparr.models.credit_type import CreditType
from whisparr.models.media_cover import MediaCover

class CreditResource(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    id: Optional[int]
    person_name: Optional[str]
    credit_tmdb_id: Optional[str]
    person_tmdb_id: Optional[int]
    movie_metadata_id: Optional[int]
    images: Optional[List]
    department: Optional[str]
    job: Optional[str]
    character: Optional[str]
    order: Optional[int]
    type: Optional[CreditType]
    __properties = ["id", "personName", "creditTmdbId", "personTmdbId", "movieMetadataId", "images", "department", "job", "character", "order", "type"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True
        alias_generator = lambda x: x.split("_")[0] + "".join(word.capitalize() for word in x.split("_")[1:])

    def __getitem__(self, item):
        return getattr(self, item)

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> CreditResource:
        """Create an instance of CreditResource from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of each item in images (list)
        _items = []
        if self.images:
            for _item in self.images:
                if _item:
                    _items.append(_item.to_dict())
            _dict['images'] = _items
        # set to None if person_name (nullable) is None
        if self.person_name is None:
            _dict['personName'] = None

        # set to None if credit_tmdb_id (nullable) is None
        if self.credit_tmdb_id is None:
            _dict['creditTmdbId'] = None

        # set to None if images (nullable) is None
        if self.images is None:
            _dict['images'] = None

        # set to None if department (nullable) is None
        if self.department is None:
            _dict['department'] = None

        # set to None if job (nullable) is None
        if self.job is None:
            _dict['job'] = None

        # set to None if character (nullable) is None
        if self.character is None:
            _dict['character'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> CreditResource:
        """Create an instance of CreditResource from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return CreditResource.parse_obj(obj)

        _obj = CreditResource.parse_obj({
            "id": obj.get("id"),
            "person_name": obj.get("personName"),
            "credit_tmdb_id": obj.get("creditTmdbId"),
            "person_tmdb_id": obj.get("personTmdbId"),
            "movie_metadata_id": obj.get("movieMetadataId"),
            "images": [MediaCover.from_dict(_item) for _item in obj.get("images")] if obj.get("images") is not None else None,
            "department": obj.get("department"),
            "job": obj.get("job"),
            "character": obj.get("character"),
            "order": obj.get("order"),
            "type": obj.get("type")
        })
        return _obj

